package tik_tok

import (
	zhios_third_party_utils "code.fnuoos.com/go_rely_warehouse/zyos_go_third_party_api.git/utils"
	"encoding/json"
	"github.com/syyongx/php2go"
	"github.com/tidwall/gjson"
)

//抖音商品
func GoodsList(args map[string]string) []TikTokGoods {
	sortArr := map[string]map[string]string{
		"default":        {"search_type": "0", "sort_type": "0"},
		"qhPriceDesc":    {"search_type": "2", "sort_type": "1"},
		"qhPriceAsc":     {"search_type": "2", "sort_type": "0"},
		"commissionDesc": {"search_type": "4", "sort_type": "1"},
		"commissionAsc":  {"search_type": "4", "sort_type": "0"},
		"salesDesc":      {"search_type": "1", "sort_type": "1"},
		"salesAsc":       {"search_type": "1", "sort_type": "0"},
	}
	params := map[string]interface{}{
		"search_type":  sortArr[args["sort"]]["search_type"],
		"sort_type":    sortArr[args["sort"]]["sort_type"],
		"page":         args["page"],
		"page_size":    args["page_size"],
		"share_status": "1",
	}
	if args["title"] != "" {
		params["title"] = args["title"]
	}
	if args["first_cids"] != "" {
		params["first_cids"] = []string{args["first_cids"]}
	}
	if args["price_min"] != "" {
		params["price_min"] = zhios_third_party_utils.Float64ToStr(zhios_third_party_utils.StrToFloat64(args["price_min"]) * 100)
	}
	if args["price_max"] != "" {
		params["price_max"] = zhios_third_party_utils.Float64ToStr(zhios_third_party_utils.StrToFloat64(args["price_max"]) * 100)
	}
	if args["sell_num_min"] != "" {
		params["sell_num_min"] = args["sell_num_min"]
	}
	if args["sell_num_max"] != "" {
		params["sell_num_max"] = args["sell_num_max"]
	}
	if args["cos_fee_min"] != "" {
		params["cos_fee_min"] = zhios_third_party_utils.Float64ToStr(zhios_third_party_utils.StrToFloat64(args["cos_fee_min"]) * 100)
	}
	if args["cos_fee_max"] != "" {
		params["cos_fee_max"] = zhios_third_party_utils.Float64ToStr(zhios_third_party_utils.StrToFloat64(args["cos_fee_max"]) * 100)
	}
	if args["cos_ratio_min"] != "" {
		params["cos_ratio_min"] = zhios_third_party_utils.Float64ToStr(zhios_third_party_utils.StrToFloat64(args["cos_ratio_min"]) * 100)
	}
	if args["cos_ratio_max"] != "" {
		params["cos_ratio_max"] = zhios_third_party_utils.Float64ToStr(zhios_third_party_utils.StrToFloat64(args["cos_ratio_max"]) * 100)
	}
	send, err := Send(args["appkey"], args["appSecret"], "alliance.materialsProductsSearch", params, args["acctoken"])
	var goodsList = make([]TikTokGoods, 0)
	product := gjson.Get(send, "data.products").String()
	if err != nil || product == "" {
		return goodsList
	}
	var tmpList = make([]interface{}, 0)
	err = json.Unmarshal([]byte(product), &tmpList)
	if err != nil {
		return goodsList
	}
	for _, v := range tmpList {
		goods := v.(map[string]interface{})
		tmp := CommGoodsDetail(goods)
		goodsList = append(goodsList, tmp)
	}
	return goodsList
}

//详情
func GetDetail(args map[string]string) TikTokGoods {
	params := map[string]interface{}{"product_ids": []string{args["id"]}, "with_share_status": true}
	send, err := Send(args["appkey"], args["appSecret"], "alliance.materialsProductsDetails", params, args["acctoken"])
	var goodsList = TikTokGoods{}
	product := gjson.Get(send, "data.products").String()
	if err != nil || product == "" {
		return goodsList
	}
	var tmpList = make([]interface{}, 0)
	err = json.Unmarshal([]byte(product), &tmpList)
	if err != nil {
		return goodsList
	}
	for _, v := range tmpList {
		goods := v.(map[string]interface{})
		tmp := CommGoodsDetail(goods)
		if tmp.GoodsID == args["id"] {
			return tmp
		}
	}
	return goodsList
}
func GetKlGoods(args map[string]string) TikTokGoods {
	params := map[string]interface{}{"command": php2go.Base64Encode(args["content"])}
	send, err := Send(args["appkey"], args["appSecret"], "buyin.shareCommandParse", params, args["acctoken"])
	var goodsList = TikTokGoods{}
	product := gjson.Get(send, "data.product_info").String()
	if err != nil || product == "" {
		return goodsList
	}
	args["id"] = gjson.Get(product, "product_id").String()
	goodsList = GetDetail(args)
	return goodsList
}
func CommGoodsDetail(goods map[string]interface{}) TikTokGoods {
	img := make([]interface{}, 0)
	imgs, ok := goods["imgs"].([]interface{})
	if ok {
		img = imgs
	}
	var tmp = TikTokGoods{
		Commission:     zhios_third_party_utils.AnyToString(goods["cos_ratio"]),
		CostPrice:      zhios_third_party_utils.Float64ToStr(zhios_third_party_utils.AnyToFloat64(goods["price"]) / 100),
		DetailURL:      zhios_third_party_utils.AnyToString(goods["detail_url"]),
		GoodsID:        zhios_third_party_utils.AnyToString(goods["product_id"]),
		GoodsImg:       zhios_third_party_utils.AnyToString(goods["cover"]),
		GoodsSales:     zhios_third_party_utils.AnyToString(goods["sales"]),
		GoodsTitle:     zhios_third_party_utils.AnyToString(goods["title"]),
		Imgs:           img,
		InStock:        zhios_third_party_utils.AnyToString(goods["in_stock"]),
		Price:          zhios_third_party_utils.Float64ToStr(zhios_third_party_utils.AnyToFloat64(goods["coupon_price"]) / 100),
		Sharable:       zhios_third_party_utils.AnyToString(goods["sharable"]),
		ShopID:         zhios_third_party_utils.AnyToString(goods["shop_id"]),
		ShopName:       zhios_third_party_utils.AnyToString(goods["shop_name"]),
		ShopTotalScore: zhios_third_party_utils.AnyToString(goods["shop_total_score"]),
		YhqPrice:       "0",
	}
	if zhios_third_party_utils.StrToFloat64(tmp.Price) == 0 {
		tmp.Price = tmp.CostPrice
	} else {
		tmp.YhqPrice = zhios_third_party_utils.Float64ToStr(zhios_third_party_utils.AnyToFloat64(goods["price"])/100 - zhios_third_party_utils.AnyToFloat64(goods["coupon_price"])/100)
	}
	return tmp

}
